autofs-5.1.2 - dont exit on master map read fail timeout

From: Ian Kent <raven@themaw.net>

If there is a persistent master map read failure autofs should
continue on after the configured retry wait, as it would have
done previously.

Signed-off-by: Ian Kent <raven@themaw.net>
---
 CHANGELOG          |    1 +
 daemon/automount.c |   12 ++++++++----
 2 files changed, 9 insertions(+), 4 deletions(-)

diff --git a/CHANGELOG b/CHANGELOG
index 5822aeb..85b1480 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -28,6 +28,7 @@ xx/xx/2016 autofs-5.1.3
 - add sss master map wait config option.
 - fix quoted key handling in sanitize_path().
 - fix included master map not found return.
+- dont exit on master map read fail timeout.
 
 15/06/2016 autofs-5.1.2
 =======================
diff --git a/daemon/automount.c b/daemon/automount.c
index 72c980e..95b8969 100644
--- a/daemon/automount.c
+++ b/daemon/automount.c
@@ -2533,10 +2533,14 @@ int main(int argc, char *argv[])
 		 * error.
 		 */
 		if (!do_master_read_master(master_list, master_wait)) {
-			logerr("%s: failed to read master map!", program);
-			master_kill(master_list);
-			release_flag_file();
-			exit(3);
+			logmsg("%s: warning: could not read at least one "
+				"map source after waiting, continuing ...",
+				 program);
+			/*
+			 * Failed to read master map, continue with what
+			 * we have anyway.
+			 */
+			master_read_master(master_list, age, 1);
 		}
 	}
 
